AccountInfo class abstract
- Implemented types
Constructors
-
AccountInfo({int? id, required int userInfoId, List<
AccountProjectBridge> ? accountprojectbridge, required String apiKey, required PlanTier planTier}) -
factory
-
AccountInfo.fromJson(Map<
String, dynamic> jsonSerialization) -
factory
Properties
-
accountprojectbridge
↔ List<
AccountProjectBridge> ? -
getter/setter pair
- apiKey ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int?
-
The database id, set if the object has been inserted into the
database or if it has been fetched from the database. Otherwise,
the id will be null.
getter/setter pair
- planTier ↔ PlanTier
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userInfoId ↔ int
-
getter/setter pair
Methods
-
copyWith(
{int? id, int? userInfoId, List< AccountProjectBridge> ? accountprojectbridge, String? apiKey, PlanTier? planTier}) → AccountInfo - Returns a shallow copy of this AccountInfo with some or all fields replaced by the given arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Returns a serialized JSON structure of the model which also includes
fields used by the database.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited