AccountProjectBridge class abstract

Implemented types

Constructors

AccountProjectBridge({int? id, required int projectId, Project? project, required int accountId, AccountInfo? account})
factory
AccountProjectBridge.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

account AccountInfo?
getter/setter pair
accountId int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int?
The database id, set if the object has been inserted into the database or if it has been fetched from the database. Otherwise, the id will be null.
getter/setter pair
project Project?
getter/setter pair
projectId int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, int? projectId, Project? project, int? accountId, AccountInfo? account}) AccountProjectBridge
Returns a shallow copy of this AccountProjectBridge with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited