ArbKeysAppearancesPath class abstract
- Implemented types
Constructors
-
ArbKeysAppearancesPath({required Map<
String, Set< pathAppearancesPerKey})String> > -
factory
-
ArbKeysAppearancesPath.fromJson(Map<
String, dynamic> jsonSerialization) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pathAppearancesPerKey
↔ Map<
String, Set< String> > -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Map< String, Set< ? pathAppearancesPerKey}) → ArbKeysAppearancesPathString> > - Returns a shallow copy of this ArbKeysAppearancesPath with some or all fields replaced by the given arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Returns a serialized JSON structure of the model which also includes
fields used by the database.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited