Methods
-
getLastUpdateSha({required String token, required BigInt projectShaIdentifier})
→ Future<List<({String sha, DateTime updatedDate})>?>
-
-
getProjectLanguages({required BigInt projectShaIdentifier})
→ Future<({List<({String countryCode, String downloadLink, String languageCode})> languages, DateTime updatedAt})>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
resetStream()
→ void
-
Resets web socket stream, so it's possible to re-listen to endpoint
streams.
inherited
-
sendStreamMessage(SerializableModel message)
→ Future<void>
-
Sends a message to the endpoint's stream.
inherited
-
sincronize({required String token, required BigInt projectShaIdentifier, required String name, required String description, required Set<String> projectCodeBaseFolders})
→ Future<void>
-
-
toString()
→ String
-
A string representation of this object.
inherited