EndpointTranslateArb class Endpoint

Inheritance

Constructors

EndpointTranslateArb(EndpointCaller caller)

Properties

caller EndpointCaller
Holds a reference to the caller class.
finalinherited
client ServerpodClientShared
Reference to the client.
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the endpoint this reference is connected to.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<SerializableModel>
Stream of messages sent from an endpoint that supports streaming.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetStream() → void
Resets web socket stream, so it's possible to re-listen to endpoint streams.
inherited
sendStreamMessage(SerializableModel message) Future<void>
Sends a message to the endpoint's stream.
inherited
toString() String
A string representation of this object.
inherited
translate({required String token, required BigInt projectShaIdentifier, required String toLanguageCode, required String toCountryCode, required String referenceLanguageCode, required String referenceCountryCode, required Map<String, String> referenceArb, required ArbKeysAppearancesPath pathsOfKeys}) Future<Map<String, String>>
Return the result of the translated strings

Operators

operator ==(Object other) bool
The equality operator.
inherited