Properties
-
countryCode
↔ String
-
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
↔ int?
-
The database id, set if the object has been inserted into the
database or if it has been fetched from the database. Otherwise,
the id will be null.
getter/setter pair
-
languageCode
↔ String
-
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith({int? id, String? languageCode, String? countryCode})
→ LabelLocale
-
Returns a shallow copy of this LabelLocale
with some or all fields replaced by the given arguments.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
Returns a serialized JSON structure of the model which also includes
fields used by the database.
override
-
toString()
→ String
-
A string representation of this object.
override