Constructors
-
Project({int? id, required String name, required DateTime createdAt, required DateTime updatedAt, required String currentTranslationsKeysSha, required BigInt projectShaIdentifier, required String description, required String projectReferenceName, List<ActiveTranslations>? activeTranslations, List<AccountProjectBridge>? accountprojectbridge, required String appContextText, required List<TranslationPathContext> contextsPerPath, required int lastShaStampId, LastUpdateShaStamp? lastShaStamp, required int codeBaseId, ProjectCodeBase? codeBase, required int pathAppearancesPerKeyId, ProjectArbKeysAppearancesPath? pathAppearancesPerKey})
-
factory
-
Project.fromJson(Map<String, dynamic> jsonSerialization)
-
factory
Methods
-
copyWith({int? id, String? name, DateTime? createdAt, DateTime? updatedAt, String? currentTranslationsKeysSha, BigInt? projectShaIdentifier, String? description, String? projectReferenceName, List<ActiveTranslations>? activeTranslations, List<AccountProjectBridge>? accountprojectbridge, String? appContextText, List<TranslationPathContext>? contextsPerPath, int? lastShaStampId, LastUpdateShaStamp? lastShaStamp, int? codeBaseId, ProjectCodeBase? codeBase, int? pathAppearancesPerKeyId, ProjectArbKeysAppearancesPath? pathAppearancesPerKey})
→ Project
-
Returns a shallow copy of this Project
with some or all fields replaced by the given arguments.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
Returns a serialized JSON structure of the model which also includes
fields used by the database.
override
-
toString()
→ String
-
A string representation of this object.
override