copyWith abstract method

  1. @useResult
Project copyWith({
  1. int? id,
  2. String? name,
  3. DateTime? createdAt,
  4. DateTime? updatedAt,
  5. String? currentTranslationsKeysSha,
  6. BigInt? projectShaIdentifier,
  7. String? description,
  8. String? projectReferenceName,
  9. List<ActiveTranslations>? activeTranslations,
  10. List<AccountProjectBridge>? accountprojectbridge,
  11. String? appContextText,
  12. List<TranslationPathContext>? contextsPerPath,
  13. int? lastShaStampId,
  14. LastUpdateShaStamp? lastShaStamp,
  15. int? codeBaseId,
  16. ProjectCodeBase? codeBase,
  17. int? pathAppearancesPerKeyId,
  18. ProjectArbKeysAppearancesPath? pathAppearancesPerKey,
})

Returns a shallow copy of this Project with some or all fields replaced by the given arguments.

Implementation

@_i1.useResult
Project copyWith({
  int? id,
  String? name,
  DateTime? createdAt,
  DateTime? updatedAt,
  String? currentTranslationsKeysSha,
  BigInt? projectShaIdentifier,
  String? description,
  String? projectReferenceName,
  List<_i2.ActiveTranslations>? activeTranslations,
  List<_i3.AccountProjectBridge>? accountprojectbridge,
  String? appContextText,
  List<_i4.TranslationPathContext>? contextsPerPath,
  int? lastShaStampId,
  _i5.LastUpdateShaStamp? lastShaStamp,
  int? codeBaseId,
  _i6.ProjectCodeBase? codeBase,
  int? pathAppearancesPerKeyId,
  _i7.ProjectArbKeysAppearancesPath? pathAppearancesPerKey,
});