toJson method
Returns a serialized JSON structure of the model which also includes fields used by the database.
Implementation
@override
dynamic toJson() {
return {};
}
Returns a serialized JSON structure of the model which also includes fields used by the database.
@override
dynamic toJson() {
return {};
}