serverRequest<T> abstract method
Performs the actual request to the server and returns the response data.
Implementation
Future<String> serverRequest<T>(
Uri url, {
required String body,
String? authenticationValue,
});
Performs the actual request to the server and returns the response data.
Future<String> serverRequest<T>(
Uri url, {
required String body,
String? authenticationValue,
});