copyWith abstract method
Returns a shallow copy of this TranslationPathContext with some or all fields replaced by the given arguments.
Implementation
@_i1.useResult
TranslationPathContext copyWith({
String? contextString,
String? path,
});
Returns a shallow copy of this TranslationPathContext with some or all fields replaced by the given arguments.
@_i1.useResult
TranslationPathContext copyWith({
String? contextString,
String? path,
});