copyWith abstract method
Project
copyWith({
- int? id,
- String? name,
- DateTime? createdAt,
- DateTime? updatedAt,
- String? currentTranslationsKeysSha,
- BigInt? projectShaIdentifier,
- String? description,
- String? projectReferenceName,
- List<
ActiveTranslations> ? activeTranslations, - List<
AccountProjectBridge> ? accountprojectbridge, - String? appContextText,
- List<
TranslationPathContext> ? contextsPerPath, - int? lastShaStampId,
- LastUpdateShaStamp? lastShaStamp,
- int? codeBaseId,
- ProjectCodeBase? codeBase,
- int? pathAppearancesPerKeyId,
- ProjectArbKeysAppearancesPath? pathAppearancesPerKey,
Returns a shallow copy of this Project with some or all fields replaced by the given arguments.
Implementation
@_i1.useResult
Project copyWith({
int? id,
String? name,
DateTime? createdAt,
DateTime? updatedAt,
String? currentTranslationsKeysSha,
BigInt? projectShaIdentifier,
String? description,
String? projectReferenceName,
List<_i2.ActiveTranslations>? activeTranslations,
List<_i3.AccountProjectBridge>? accountprojectbridge,
String? appContextText,
List<_i4.TranslationPathContext>? contextsPerPath,
int? lastShaStampId,
_i5.LastUpdateShaStamp? lastShaStamp,
int? codeBaseId,
_i6.ProjectCodeBase? codeBase,
int? pathAppearancesPerKeyId,
_i7.ProjectArbKeysAppearancesPath? pathAppearancesPerKey,
});